/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.flowdepth;

import org.dive4elements.river.model.BedHeight;

/**
 * Basic infos about a {@link BedHeight}.
 *
 * @author Gernot Belger
 */
final class BedHeightInfo {

    private final Integer year;

    private final String description;

    private final String type;

    private final String locationSystem;

    private final String curElevationModelName;

    private final String oldElevationModelName;

    public static BedHeightInfo from(final BedHeight bedHeight) {
        return new BedHeightInfo(bedHeight);
    }

    private BedHeightInfo(final BedHeight bedHeight) {

        this.year = bedHeight.getYear();

        // private String evaluationBy;
        this.description = bedHeight.getDescription();

        this.type = bedHeight.getType().getName();

        this.locationSystem = bedHeight.getLocationSystem().getName();

        this.curElevationModelName = bedHeight.getCurElevationModel().getName();
        this.oldElevationModelName = bedHeight.getCurElevationModel().getName();
    }

    public Integer getYear() {
        return this.year;
    }

    public String getDescription() {
        return this.description;
    }

    public String getType() {
        return this.type;
    }

    public String getLocationSystem() {
        return this.locationSystem;
    }

    public String getCurElevationModelName() {
        return this.curElevationModelName;
    }

    public String getOldElevationModelName() {
        return this.oldElevationModelName;
    }
}
